@@ -1,14 +1,14 @@
 #!/usr/bin/env python3
 
 import numpy as np
-import fadScal
-import fadVect
-import revScal
-import revVect
-# from fad.Gradients import Scal as fadScal
-# from fad.Matrices import Vect as fadVect
-# from rev.Gradients import Scal as revScal
-# from rev.Matrices import Vect as revVect
+# import fadScal
+# import fadVect
+# import revScal
+# import revVect
+from fad.Gradients import Scal as fadScal
+from fad.Matrices import Vect as fadVect
+from rev.Gradients import Scal as revScal
+from rev.Matrices import Vect as revVect
 
 
 def sin(x):
