@@ -1,12 +1,9 @@
 import pytest
 import coverage
-# from FADiff import FADiff
-import FADiff
+from FADiff import FADiff
 import Elems
 import numpy as np
-# from FuncVect import FuncVect
-import FuncVect
-
+from FuncVect import FuncVect
 
 class TestClass:
     FADiff.set_mode('forward')
